from Moebelprojekt.leinwand import Leinwand
class Tisch:
    """
    Stellt einen Tisch im Möbelplaner dar.
    """
    def __init__(self,xPosition=50,yPosition=50,breite=120,tiefe=60,farbe='blau'):
        """
        Erzeugt einen Tisch an der gegebenen Position.
        xPosition: die x-Koordinate der Mitte des Tischs
        yPosition: die y-Koordinate der Mitte des Tischs
        breite: horizontale Ausdehnung bei winkel 0
        tiefe: vertikale Ausdehnung bei winkel 0
        farbe: die Farbe, in der der Tisch angezeigt werden soll.
               Dies sollte einer der Farbnamen der Klasse Farben sein.  
        """
        self.xPosition = xPosition
        self.yPosition = yPosition
        self.breite = breite
        self.tiefe = tiefe
        self.winkel = 0
        self.farbe = farbe
        self.formen = []
        self.leinwand = Leinwand()

    def zeige(self):
        """
        Zeigt diesen Tisch im Möbelplaner an.
        """
        if not self.formen:
            tisch = self.leinwand.polygon(self.xPosition,self.yPosition,\
                                          self.xPosition+self.breite,self.yPosition,\
                                          self.xPosition+self.breite,self.yPosition+self.tiefe,\
                                          self.xPosition,self.yPosition+self.tiefe)
            self.leinwand.farbeAendern(tisch,"transparent")
            self.leinwand.randfarbeAendern(tisch,self.farbe)
            self.formen.append(tisch)
            xMitte,yMitte=self.xPosition+self.breite//2,self.yPosition+self.tiefe//2
            for form in self.formen:
                self.leinwand.drehe(form,xMitte,yMitte,self.winkel)

    def verberge(self):
        """
        Entfernt diesen Tisch aus der Ansicht im Möbelplaner.
        """
        for form in self.formen:
            self.leinwand.loesche(form)
        self.formen = []

    def drehe(self,umWinkel):
        """
        Dreht den Tisch.
        umWinkel: der Winkel in Grad, um den im Uhrzeigersinn gedreht werden soll
        """
        self.verberge()
        self.winkel = (self.winkel + umWinkel) % 360
        self.zeige()

    def horizontalBewegen(self,entfernung):
        """
        Bewegt den Tisch in horizontaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach rechts
                    bewegt werden soll. Für Bewegungen nach links sind
                    negative Zahlen zu verwenden.
        """
        self.verberge()
        self.xPosition+=entfernung
        self.zeige()
        
    def vertikalBewegen(self,entfernung):
        """
        Bewegt den Tisch in vertikaler Richtung auf der Leinwand.
        entfernung: die Anzahl an Pixeln, um die der Tisch nach unten
                    bewegt werden soll. Für Bewegungen nach oben sind
                    negative Zahlen zu verwenden.
        """
        self.verberge()
        self.yPosition+=entfernung
        self.zeige()

    def breiteAendern(self,neueBreite):
        """
        Aendert die Breite des Tischs
        neueBreite ersetzt den alten Wert
        """
        self.verberge()
        self.breite = neueBreite
        self.zeige()
        
    def tiefeAendern(self,neueTiefe):
        """
        Aendert die Tiefe des Tischs
        neueTiefe ersetzt den alten Wert
        """
        self.verberge()
        self.tiefe = neueTiefe
        self.zeige()
